==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/db2/db2/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("IBM DB2 Data Driver")
url = "ftp://people.linuxkorea.co.kr/pub/DB2/"
doc = """
Description
-----------
A DB/2 driver from Bryan Lee.  Works with IBM's DB/2 version 7.1.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP (Installer available)


Connection Properties
---------------------
* service  -- This is the DB2 DSN for your connection  (required)

Examples
--------
  [myconn]
  provider=db2            # Use the DB/2 adapter
  service=mydsn           # The DSN connection string of the database

Notes
-----
1. The Win32 binaries are included in the tar'ed file (in win32/)

2. This driver has not been fully tested.  If you are successfully using
   this driver, please let us know.
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/db2/db2/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("IBM DB2 Data Driver")
url = "ftp://people.linuxkorea.co.kr/pub/DB2/"
doc = """
Description
-----------
A DB/2 driver from Bryan Lee.  Works with IBM's DB/2 version 7.1.

Support
-------
Supported Platforms:

  - Linux/BSD
  - MS Windows 98/NT/2000/XP (Installer available)


Connection Properties
---------------------
* service  -- This is the DB2 DSN for your connection  (required)

Examples
--------
  [myconn]
  provider=db2            # Use the DB/2 adapter
  service=mydsn           # The DSN connection string of the database

Notes
-----
1. The Win32 binaries are included in the tar'ed file (in win32/).

2. This driver has not been fully tested and is currently unmaintained.
   If you are successfully using this driver, please let us know.

2. this driver does not support index introspection
"""
